// File: views.idl 
#ifndef _VIEWS_IDL_ 
#define _VIEWS_IDL_ 
#include "dom.idl" 
#pragma prefix "dom.w3c.org" 
module views 
{ 
  interface DocumentView; 
  // Introduced in DOM Level 2: 
  interface AbstractView { 
    readonly attribute DocumentView     document; 
  }; 
  // Introduced in DOM Level 2: 
  interface DocumentView { 
    readonly attribute AbstractView     defaultView; 
  }; 
}; 
#endif // _VIEWS_IDL_ 
